@@ -137,7 +137,8 @@ struct abbrev VerseKey::abbrevs[] = {
 	{"E", 49  }, //     Ephesians
 	{"ECCLESIASTES", 21   }, //    Ecclesiastes
 	{"EPHESIANS", 49   }, //    Ephesians
-	{"ESTER", 17   }, //    Ester
+	{"ESTER", 17   }, //    Esther
+	{"ESTHER", 17   }, //    Esther
 	{"EXODUS", 2   }, //    Exodus
 	{"EZEKIEL", 26   }, //   Ezekiel
 	{"EZRA", 15   }, //   Ezra
