@@ -13,7 +13,7 @@
 #include <swfilter.h>
 #include <list>
 
-using namespace std;
+ using namespace std;
 
 typedef list<SWFilter *> FilterList;
 
@@ -35,7 +35,7 @@ public:
 	SWModule(const char *imodname = 0, const char *imoddesc = 0, SWDisp *idisp = 0, char *imodtype = 0);
 	virtual ~SWModule();
 	virtual char Error();
-	virtual char SetKey(SWKey &ikey);
+	virtual char SetKey(const SWKey &ikey);
 	virtual const char *KeyText(char *imodtype = 0);
 	virtual char Display();
 	virtual SWDisp *Disp(SWDisp *idisp = 0);
@@ -50,8 +50,8 @@ public:
 	virtual operator SWKey&() { return *key; }
 	virtual operator SWKey*() { return key; }
 
-	virtual SWModule &operator <<(const char *inbuf) { return *this; }  // Modify current module entry
-	virtual SWModule &operator <<(const SWKey *inkey) { return *this; } // Link current module entry to other module entry
+	virtual SWModule &operator <<(const char *) { return *this; }  // Modify current module entry
+	virtual SWModule &operator <<(const SWKey *) { return *this; } // Link current module entry to other module entry
 	virtual void Delete() {} // Delete current module entry
 
 	virtual SWModule &operator -=(int decrement);
@@ -59,8 +59,8 @@ public:
 	virtual SWModule &operator ++(int) { return *this += 1; }
 	virtual SWModule &operator --(int) { return *this -= 1; }
 	virtual SWModule &operator =(POSITION);
-	virtual SWModule &AddRenderFilter(SWFilter *newfilter) { renderfilters.insert(renderfilters.end(), newfilter); }
-	virtual SWModule &AddStripFilter(SWFilter *newfilter) { stripfilters.insert(stripfilters.end(), newfilter); }
+	virtual SWModule &AddRenderFilter(SWFilter *newfilter) { renderfilters.insert(renderfilters.end(), newfilter); return *this;}
+	virtual SWModule &AddStripFilter(SWFilter *newfilter) { stripfilters.insert(stripfilters.end(), newfilter); return *this;}
 	virtual const char *StripText(char *text = 0, int len = -1);
 	virtual const char *RenderText(char *text = 0, int len = -1);
 };
