@@ -49,16 +49,16 @@ RawVerse::RawVerse(const char *ipath)
 #define O_BINARY 0		// If it hasn't been defined than we probably
 #endif				// don't need it.
 	sprintf(buf, "%sot.vss", path);
-	idxfp[0] = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY);
+	idxfp[0] = FileMgr::systemFileMgr.open(buf, O_RDWR|O_BINARY);
 
 	sprintf(buf, "%snt.vss", path);
-	idxfp[1] = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY);
+	idxfp[1] = FileMgr::systemFileMgr.open(buf, O_RDWR|O_BINARY);
 
 	sprintf(buf, "%sot", path);
-	textfp[0] = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY);
+	textfp[0] = FileMgr::systemFileMgr.open(buf, O_RDWR|O_BINARY);
 
 	sprintf(buf, "%snt", path);
-	textfp[1] = FileMgr::systemFileMgr.open(buf, O_RDONLY|O_BINARY);
+	textfp[1] = FileMgr::systemFileMgr.open(buf, O_RDWR|O_BINARY);
 	
 	instance++;
 }
@@ -88,9 +88,7 @@ RawVerse::~RawVerse()
  * RawVerse::findoffset	- Finds the offset of the key verse from the indexes
  *
  * ENT: testmt	- testament to find (0 - Bible/module introduction)
- *	book	- book      to find (0 - testament    introduction)
- *	chapter	- chapter   to find (0 - book         introduction)
- *	verse	- verse     to find (0 - chapter      introduction)
+ *	idxoff	- offset into .vss
  *	start	- address to store the starting offset
  *	size	- address to store the size of the entry
  */
@@ -181,3 +179,31 @@ void RawVerse::gettext(char testmt, long start, unsigned short size, char *buf)
 	lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
 	read(textfp[testmt-1]->getFd(), buf, (int)size - 1);
 }
+
+
+/******************************************************************************
+ * RawVerse::settext	- Sets text for current offset
+ *
+ * ENT: testmt	- testament to find (0 - Bible/module introduction)
+ *	idxoff	- offset into .vss
+ *	buf	- buffer to store
+ */
+
+void RawVerse::settext(char testmt, long idxoff, const char *buf)
+{
+	long start;
+	unsigned short size;
+
+	idxoff *= 6;
+	if (!testmt)
+		testmt = ((idxfp[1]) ? 1:2);
+
+	lseek(idxfp[testmt-1]->getFd(), idxoff, SEEK_SET);
+	read(idxfp[testmt-1]->getFd(), &start, 4);
+
+	size = strlen(buf);
+	write(idxfp[testmt-1]->getFd(), &size, 2);
+
+	lseek(textfp[testmt-1]->getFd(), start, SEEK_SET);
+	write(textfp[testmt-1]->getFd(), buf, (int)size);
+}
