@@ -171,7 +171,7 @@ char SWModule::Display()
  * RET:	error status
  */
 
-char SWModule::SetKey(SWKey &ikey)
+char SWModule::SetKey(const SWKey &ikey)
 {
 	if (key) {
 		if (!key->Persist())	// if we have our own copy
@@ -182,7 +182,7 @@ char SWModule::SetKey(SWKey &ikey)
 		 key = CreateKey();
 		*key = ikey;
 	}
-	else	 key = &ikey;		// if we are to just point to an external key
+	else	 key = (SWKey *)&ikey;		// if we are to just point to an external key
 
 	return 0;
 }
@@ -200,7 +200,7 @@ char SWModule::SetKey(SWKey &ikey)
 const char *SWModule::KeyText(char *ikeytext)
 {
 	if (ikeytext)
-		SetKey(ikeytext);
+		SetKey((const char *)ikeytext);
 		
 	return *key;
 }
